@@ -1,7 +1,8 @@
 import importlib
 import sys
 from contextlib import contextmanager
-from typing import Callable, Optional
+from dataclasses import dataclass, field
+from typing import Callable, Generator, Optional
 
 from itemadapter import ItemAdapter
 
@@ -17,7 +18,7 @@ def make_mock_import(block_name: str) -> Callable:
 
 
 @contextmanager
-def clear_itemadapter_imports() -> None:
+def clear_itemadapter_imports() -> Generator[None, None, None]:
     backup = {}
     for key in sys.modules.copy().keys():
         if key.startswith("itemadapter"):
@@ -28,6 +29,39 @@ def clear_itemadapter_imports() -> None:
         sys.modules.update(backup)
 
 
+@dataclass
+class DataClassItem:
+    name: str = field(default_factory=lambda: None, metadata={"serializer": str})
+    value: int = field(default_factory=lambda: None, metadata={"serializer": int})
+
+
+@dataclass
+class DataClassItemNested:
+    nested: DataClassItem
+    adapter: ItemAdapter
+    dict_: dict
+    list_: list
+    set_: set
+    tuple_: tuple
+    int_: int
+
+
+@dataclass(init=False)
+class DataClassWithoutInit:
+    name: str = field(metadata={"serializer": str})
+    value: int = field(metadata={"serializer": int})
+
+
+@dataclass
+class DataClassItemSubclassed(DataClassItem):
+    subclassed: bool = True
+
+
+@dataclass
+class DataClassItemEmpty:
+    pass
+
+
 try:
     import attr
 except ImportError:
@@ -67,45 +101,6 @@ else:
         pass
 
 
-try:
-    from dataclasses import dataclass, field
-except ImportError:
-    DataClassItem = None
-    DataClassItemNested = None
-    DataClassWithoutInit = None
-    DataClassItemSubclassed = None
-    DataClassItemEmpty = None
-else:
-
-    @dataclass
-    class DataClassItem:
-        name: str = field(default_factory=lambda: None, metadata={"serializer": str})
-        value: int = field(default_factory=lambda: None, metadata={"serializer": int})
-
-    @dataclass
-    class DataClassItemNested:
-        nested: DataClassItem
-        adapter: ItemAdapter
-        dict_: dict
-        list_: list
-        set_: set
-        tuple_: tuple
-        int_: int
-
-    @dataclass(init=False)
-    class DataClassWithoutInit:
-        name: str = field(metadata={"serializer": str})
-        value: int = field(metadata={"serializer": int})
-
-    @dataclass
-    class DataClassItemSubclassed(DataClassItem):
-        subclassed: bool = True
-
-    @dataclass
-    class DataClassItemEmpty:
-        pass
-
-
 try:
     from pydantic import BaseModel, Field as PydanticField
 except ImportError:
